@@ -5,14 +5,16 @@
 extern "C" {
 #endif
 
-#define XMP_VERSION "4.2.0"
-#define XMP_VERCODE 0x040200
+#define XMP_VERSION "4.3.5"
+#define XMP_VERCODE 0x040305
 #define XMP_VER_MAJOR 4
-#define XMP_VER_MINOR 2
-#define XMP_VER_RELEASE 0
+#define XMP_VER_MINOR 3
+#define XMP_VER_RELEASE 5
 
 #if defined(_WIN32) && !defined(__CYGWIN__)
-# ifdef BUILDING_DLL
+# if defined(BUILDING_STATIC)
+#  define EXPORT
+# elif defined(BUILDING_DLL)
 #  define EXPORT __declspec(dllexport)
 # else
 #  define EXPORT __declspec(dllimport)
@@ -21,6 +23,8 @@ extern "C" {
 # define EXPORT __attribute__((visibility ("default")))
 #elif defined(__SUNPRO_C)
 # define EXPORT __global
+#elif defined(EMSCRIPTEN)
+# define EXPORT EMSCRIPTEN_KEEPALIVE
 #else
 # define EXPORT 
 #endif
@@ -38,7 +42,7 @@ extern "C" {
 #define XMP_FORMAT_UNSIGNED	(1 << 1) /* Mix to unsigned samples */
 #define XMP_FORMAT_MONO		(1 << 2) /* Mix to mono instead of stereo */
 
-/* mixer paramters for xmp_set_player() */
+/* player parameters */
 #define XMP_PLAYER_AMP		0	/* Amplification factor */
 #define XMP_PLAYER_MIX		1	/* Stereo mixing */
 #define XMP_PLAYER_INTERP	2	/* Interpolation type */
@@ -49,6 +53,7 @@ extern "C" {
 #define XMP_PLAYER_VOLUME	7	/* Player module volume */
 #define XMP_PLAYER_STATE	8	/* Internal player state */
 #define XMP_PLAYER_SMIX_VOLUME	9	/* SMIX volume */
+#define XMP_PLAYER_DEFPAN	10	/* Default pan setting */
 
 /* interpolation types */
 #define XMP_INTERP_NEAREST	0	/* Nearest neighbor */
@@ -311,6 +316,7 @@ EXPORT int         xmp_set_player      (xmp_context, int, int);
 EXPORT int         xmp_get_player      (xmp_context, int);
 EXPORT int         xmp_set_instrument_path (xmp_context, char *);
 EXPORT int         xmp_load_module_from_memory (xmp_context, void *, long);
+EXPORT int         xmp_load_module_from_file (xmp_context, void *, long);
 
 /* External sample mixer API */
 EXPORT int         xmp_start_smix       (xmp_context, int, int);
